==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/TypedErrorInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.TypedErrorInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type
 */
public data class TypedErrorInfoArgs(
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.TypedErrorInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.TypedErrorInfoArgs =
        com.pulumi.azurenative.providerhub.inputs.TypedErrorInfoArgs.builder()
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TypedErrorInfoArgs].
 */
@PulumiTagMarker
public class TypedErrorInfoArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("eqrejwnheidejwle")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("ehlleiqfkpockqmv")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): TypedErrorInfoArgs = TypedErrorInfoArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/TypedErrorInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.TypedErrorInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type
 */
public data class TypedErrorInfoArgs(
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.TypedErrorInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.TypedErrorInfoArgs =
        com.pulumi.azurenative.providerhub.inputs.TypedErrorInfoArgs.builder()
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TypedErrorInfoArgs].
 */
@PulumiTagMarker
public class TypedErrorInfoArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("svibogipfqxqoghf")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("ivqwtpoyampegryi")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): TypedErrorInfoArgs = TypedErrorInfoArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
